aboutsummaryrefslogtreecommitdiff
path: root/sound/shorten.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'sound/shorten.cpp')
-rw-r--r--sound/shorten.cpp6
1 files changed, 2 insertions, 4 deletions
diff --git a/sound/shorten.cpp b/sound/shorten.cpp
index fa62080c9c..44f4e66ed8 100644
--- a/sound/shorten.cpp
+++ b/sound/shorten.cpp
@@ -523,10 +523,8 @@ AudioStream *makeShortenStream(Common::SeekableReadStream &stream) {
if (!data)
return 0;
- // Since we allocated our own buffer for the data, we must set the autofree flag.
- flags |= Audio::Mixer::FLAG_AUTOFREE;
-
- return makeRawMemoryStream(data, size, rate, flags, 0, 0);
+ // Since we allocated our own buffer for the data, we must specify DisposeAfterUse::YES.
+ return makeRawMemoryStream(data, size, DisposeAfterUse::YES, rate, flags, 0, 0);
}
} // End of namespace Audio